//
// Copyright (c) 2000 by Tech Soft 3D, LLC.
// The information contained herein is confidential and proprietary to
// Tech Soft 3D, LLC., and considered a trade secret as defined under
// civil and criminal statutes.  Tech Soft 3D shall pursue its civil
// and criminal remedies in the event of unauthorized use or misappropriation
// of its trade secrets.  Use of this information by anyone other than
// authorized employees of Tech Soft 3D, LLC. is granted only under a
// written non-disclosure agreement, expressly prescribing the scope and
// manner of such use.
//
// $Header: /files/homes/master/cvs/hoops_master/docs_hoops/HoopsMFC/CHoopsFrm.h,v 1.2 2006-08-07 20:39:02 stage Exp $
//

// CHoopsFrm.h : interface of the CHoopsFrame class, derived from CMDIFrameWnd
// Manages palette creation and sharing per HOOPS MDI requirements

#ifndef hoops_frame
#define hoops_frame


//! The CHoopsFrame class provides a HOOPS-specific implementation of the CMDIFrameWnd object.
/*!
	CHoopsFrame encapsulates palette sharing/management when using HOOPS in conjuction with MFC.

	This is the base class from which all custom HOOPS-based MFC/MDI CMDIFrameWnd objects should be derived.
*/
class AFX_EXT_CLASS CHoopsFrame : public CMDIFrameWnd
{
	DECLARE_DYNAMIC(CHoopsFrame);

// Attributes

protected:

    CPalette    *m_pPalette; /*!< Pointer to the palette which is shared by all the views */

    BOOL        m_bSharePalette;  /*!< Indicates whether the palette should be shared by all the views */

public:
	CHoopsFrame();

    /*! 
	  Custom constructor
	  \param share Indicates whether a single palette should be shared by all the views
	*/
    CHoopsFrame(BOOL share); 


// Operations
public:
	/*! \return A pointer to the shared palette */
    CPalette    *GetSharedPalette() {return m_pPalette;};

	/*! \return Whether or not the palette is shared */
    BOOL        IsPaletteShared() {return m_bSharePalette;};

	/* Sets whether the palette should be shared */
    void        SetPaletteShared(BOOL share);

	void		SetPaneText(int index, char * text); 

 
// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CHoopsFrame)
	public:
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Implementation
public:
	virtual ~CHoopsFrame();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:  // control bar embedded members
	CStatusBar  m_wndStatusBar;
	CToolBar    m_wndToolBar;

// Generated message map functions
protected:
	//{{AFX_MSG(CHoopsFrame)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg BOOL OnQueryNewPalette();
	afx_msg void OnPaletteChanged(CWnd* pFocusWnd);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

#endif
/////////////////////////////////////////////////////////////////////////////
